summaryrefslogtreecommitdiffstats
path: root/kpresenter/KPrDocument.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpresenter/KPrDocument.h')
-rw-r--r--kpresenter/KPrDocument.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kpresenter/KPrDocument.h b/kpresenter/KPrDocument.h
index c51060a4..3584e372 100644
--- a/kpresenter/KPrDocument.h
+++ b/kpresenter/KPrDocument.h
@@ -166,7 +166,7 @@ class KPrDocument : public KoDocument
virtual void addView( KoView *_view );
virtual void removeView( KoView *_view );
- // page tqlayout
+ // page layout
void setPageLayout( const KoPageLayout &);
virtual TQPixmap generatePreview( const TQSize &size );
@@ -236,11 +236,11 @@ class KPrDocument : public KoDocument
void deletePage( int _page );
void copyPageToClipboard( int pgnum );
- // tqrepaint all views
- void tqrepaint( bool );
+ // repaint all views
+ void repaint( bool );
- void tqrepaint( const TQRect& );
- void tqrepaint( KPrObject* );
+ void repaint( const TQRect& );
+ void repaint( KPrObject* );
// stuff for screen-presentations
/**
@@ -461,8 +461,8 @@ class KPrDocument : public KoDocument
KoCommandHistory * commandHistory()const { return m_commandHistory; }
void updateObjectStatusBarItem();
void updateObjectSelected();
- void tqlayout(KPrObject *kpobject);
- void tqlayout();
+ void layout(KPrObject *kpobject);
+ void layout();
void changeBgSpellCheckingState( bool b );
bool cursorInProtectedArea()const;
@@ -552,7 +552,7 @@ protected:
void testAndCloseAllTextObjectProtectedContent();
// ************ functions ************
/**
- * Overloaded function from @ref Document_impl. Saves all tqchildren.
+ * Overloaded function from @ref Document_impl. Saves all children.
*/
virtual bool saveChildren( KoStore* _store );
@@ -707,8 +707,8 @@ private:
KPrLoadingInfo *m_loadingInfo;
TQValueList<int> *m_customListTest;
- /// here the amount of existing tqchildren before inserting a page/file
- /// is saved, so that we load the correct tqchildren
+ /// here the amount of existing children before inserting a page/file
+ /// is saved, so that we load the correct children
int m_childCountBeforeInsert;
};